/*
 * This file is part of Pustefix.
 *
 * Pustefix is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Pustefix is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Pustefix; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.pustefixframework.editor.generated;

import de.schlund.util.statuscodes.StatusCode;
import de.schlund.util.statuscodes.StatusCodeException;
import de.schlund.util.statuscodes.StatusCodeHelper;
import java.lang.reflect.Field;
import java.net.URI;
import java.net.URISyntaxException;

public class EditorStatusCodes {

    public static StatusCode getStatusCodeByName(String name) throws StatusCodeException {
        return getStatusCodeByName(name, false);
    }

    public static StatusCode getStatusCodeByName(String name, boolean optional) throws StatusCodeException {
        String     fieldname = StatusCode.convertToFieldName(name);
        StatusCode scode     = null;
        try {
            Field field = EditorStatusCodes.class.getField(fieldname);
            scode = (StatusCode) field.get(null);
        } catch (NoSuchFieldException e) {
            //
        } catch (SecurityException e) {
            //
        } catch (IllegalAccessException e) {
            //
        }
        if (scode == null && optional == false) {
            throw new StatusCodeException("StatusCode " + name + " is not defined.");
        }
        return scode;
    }

    public static final URI[] __URI;

    static {
        try {
            __URI = StatusCodeHelper.update(new URI[] {
                new URI("docroot:/dyntxt/statusmessages.xml")
            });
        } catch (URISyntaxException e) {
            throw new RuntimeException("Illegal URI", e);
        }
    };

    public static final StatusCode ADDUSER_USER_EXISTS = new StatusCode("adduser.USER_EXISTS", __URI[0]);
    public static final StatusCode AUTH_NO_LOGIN_ALLOWED = new StatusCode("auth.NO_LOGIN_ALLOWED", __URI[0]);
    public static final StatusCode AUTH_WRONG_USER_OR_PASS = new StatusCode("auth.WRONG_USER_OR_PASS", __URI[0]);
    public static final StatusCode COMMONS_COMMONPATH_UNDEF = new StatusCode("commons.COMMONPATH_UNDEF", __URI[0]);
    public static final StatusCode IMAGES_IMAGE_UNDEF = new StatusCode("images.IMAGE_UNDEF", __URI[0]);
    public static final StatusCode IMAGESUPLOAD_IMAGEUPL_GENERR = new StatusCode("imagesupload.IMAGEUPL_GENERR", __URI[0]);
    public static final StatusCode IMAGESUPLOAD_IMAGEUPL_NOFILE = new StatusCode("imagesupload.IMAGEUPL_NOFILE", __URI[0]);
    public static final StatusCode IMAGESUPLOAD_IMAGEUPL_WRONGTYPE = new StatusCode("imagesupload.IMAGEUPL_WRONGTYPE", __URI[0]);
    public static final StatusCode IMAGESUPLOAD_IMAGEUPL_WRONGTYPEGIF = new StatusCode("imagesupload.IMAGEUPL_WRONGTYPEGIF", __URI[0]);
    public static final StatusCode IMAGESUPLOAD_IMAGEUPL_WRONGTYPEJPG = new StatusCode("imagesupload.IMAGEUPL_WRONGTYPEJPG", __URI[0]);
    public static final StatusCode IMAGESUPLOAD_IMAGEUPL_WRONGTYPEPNG = new StatusCode("imagesupload.IMAGEUPL_WRONGTYPEPNG", __URI[0]);
    public static final StatusCode IMAGESUPLOAD_IMAGEUPL_HASCHANGED = new StatusCode("imagesupload.IMAGEUPL_HASCHANGED", __URI[0]);
    public static final StatusCode IMAGESUPLOAD_FILE_IS_IN_ROOT = new StatusCode("imagesupload.FILE_IS_IN_ROOT", __URI[0]);
    public static final StatusCode INCLUDES_INCLUDE_UNDEF = new StatusCode("includes.INCLUDE_UNDEF", __URI[0]);
    public static final StatusCode INCLUDES_BRANCH_CREATE_FAILED = new StatusCode("includes.BRANCH_CREATE_FAILED", __URI[0]);
    public static final StatusCode INCLUDES_BRANCH_DELETE_FAILED = new StatusCode("includes.BRANCH_DELETE_FAILED", __URI[0]);
    public static final StatusCode INCLUDESUPLOAD_GEN_ERR = new StatusCode("includesupload.GEN_ERR", __URI[0]);
    public static final StatusCode INCLUDESUPLOAD_PARSE_ERR = new StatusCode("includesupload.PARSE_ERR", __URI[0]);
    public static final StatusCode INCLUDESUPLOAD_PARSE_ERR_WITH_DETAILS = new StatusCode("includesupload.PARSE_ERR_WITH_DETAILS", __URI[0]);
    public static final StatusCode INCLUDESUPLOAD_INCLUDE_HAS_CHANGED = new StatusCode("includesupload.INCLUDE_HAS_CHANGED", __URI[0]);
    public static final StatusCode INCLUDESUPLOAD_INCLUDE_HAS_CHANGED_RESTORE = new StatusCode("includesupload.INCLUDE_HAS_CHANGED_RESTORE", __URI[0]);
    public static final StatusCode INCLUDESUPLOAD_FILE_IS_IN_ROOT = new StatusCode("includesupload.FILE_IS_IN_ROOT", __URI[0]);
    public static final StatusCode PAGES_PAGE_UNDEF = new StatusCode("pages.PAGE_UNDEF", __URI[0]);
    public static final StatusCode PRODUCTSELECT_UNKNOWN_PRODUCT = new StatusCode("productselect.UNKNOWN_PRODUCT", __URI[0]);
    public static final StatusCode SEARCH_S_INT = new StatusCode("search.S_INT", __URI[0]);
    public static final StatusCode SEARCH_S_OK = new StatusCode("search.S_OK", __URI[0]);
    public static final StatusCode SEARCH_S_RESET = new StatusCode("search.S_RESET", __URI[0]);
    public static final StatusCode SEARCH_S_RUNNING = new StatusCode("search.S_RUNNING", __URI[0]);
    public static final StatusCode TARGETS_TARGET_UNDEF = new StatusCode("targets.TARGET_UNDEF", __URI[0]);
    public static final StatusCode USERDATA_PWD_NO_MATCH = new StatusCode("userdata.PWD_NO_MATCH", __URI[0]);
    public static final StatusCode USERDATA_CHANGES_SAVED = new StatusCode("userdata.CHANGES_SAVED", __URI[0]);
    public static final StatusCode USERFOREDIT_USER_UNDEF = new StatusCode("userforedit.USER_UNDEF", __URI[0]);
    public static final StatusCode LUCEFIX_INDEX_NOT_INITED = new StatusCode("lucefix.INDEX_NOT_INITED", __URI[0]);
    public static final StatusCode LUCEFIX_PREFIX_WILDCARD_FORBIDDEN = new StatusCode("lucefix.PREFIX_WILDCARD_FORBIDDEN", __URI[0]);
    public static final StatusCode LUCEFIX_TOO_MANY_CLAUSES = new StatusCode("lucefix.TOO_MANY_CLAUSES", __URI[0]);
}
